#! /bin/sh

die () {
  echo "ERROR: $@"
  exit 1
}

#-------------------------------------------------
#        THIS SECTION NEEDS TO BE EDITED  !!!    |
#-------------------------------------------------

# uncomment and modify these four variables for your system
#   location where SAS is installed in your system
#     (something like /usr/local/sas/xmmsas)
SAS_DIR=
#   location of your odf directory
SAS_ODF=
#   proposal ID (second set of number in filenames)
obs=
#   revolution number
rev=
#   observation type (S for scheduled observation, U for unscheduled)
otype=S
#   unit numbers (from $SAS_ODF/*R1*AUX.FIT for expno1 located in odf directory)
#                      $SAS_ODF/R2*AUX.FIT for expno2
expno1=004
expno2=005
#   it is advised to indicate the coordinates
#    instead of relying on the pointing
#    set withsrc either y (yes) or n (no)
#    and give coordinates in decimal degrees
#     (srcdec=deg+min/60.+sec/3600.
#      srcra =15*(hrs+min/60.+sec/3600.)
withsrc=n
srcra=
srcdec=
#   set binning for response matrices
#    set to one if one need for wavelength scale
#    other wise set to 4000
ebins=1

#----------------------------------------------------
#     from here on no changes should be necessary   |
#----------------------------------------------------

[ "${SAS_DIR}x" != x ] || die "SAS_DIR not set; you must edit the script file"
export SAS_DIR
[ "${SAS_ODF}x" != x ] || die "SAS_ODF not set"
export SAS_ODF
[ "${obs}x" != x ] || die "obs not set"
export obs
[ "${rev}x" != x ] || die "rev not set"
export rev
did=P${obs}; export did
[ "${otype}x" != x ] || die "otype not set"
export otype
[ "${expno1}x" != x ] || die "expno1 not set"
export expno1
[ "${expno2}x" != x ] || die "expno2 not set"
export expno2
[ "${withsrc}x" != x ] || die "withsrc not set"
export withsrc
[ "${ebins}x" != x ] || die "ebins not set"
export ebins

pt=1
 if [ "x$withsrc" == "xy" ]
   then
   pt=3
   [ "${srcra}x" != x ] || die "srcra not set"
   [ "${srcdec}x" != x ] || die "srcdec not set"
 fi
export pt
export srcra
export srcdec

#------------odf preparation-----------
cd ${SAS_ODF}
chmod u+w *
chmod u+wx .
echo Changing small letters to capitals in ${SAS_ODF}
list=`ls *`; for ff in $list; do nn=`echo $ff | tr [:lower:] [:upper:]`; mv $ff $nn >/dev/null 2>&1; done
cd ..
[ -d ./mydata ] || mkdir mydata 
cd mydata

#----setup XMM_SAS--------------------
  SAS_PATH=$SAS_DIR; export SAS_PATH
  SAS_CCFPATH=$SAS_DIR/ccf; export SAS_CCFPATH
echo setting up xmmsas
  . $SAS_DIR/sas-setup.sh
  [ $? = 0 ] || die "$SAS_DIR/sas-setup.sh failed"


#----------calibration files---------------
if [ -f ccf.cif ]; then echo using $PWD/ccf.cif as SAS_CCF; else
 echo '  producing calibration file ccf.cif with cifbuild command...'
  cifbuild withccfpath=yes ccfpath=$SAS_DIR/ccf/ fullpath=yes
  [ $? = 0 ] || die "cifbuild failed"
 echo '  ...done'
fi

  SAS_CCF=${SAS_ODF}../mydata/ccf.cif; export SAS_CCF

#---------odfingest----------------

list=`ls $SAS_ODF/*.SAS`
if [ "${list}x" == x ]; then
 echo '  running odfingest...'
  odfingest outdir=$SAS_ODF odfdir=$SAS_ODF
  [ $? = 0 ] || die "odfingest failed"
 echo '  ...done'
fi
list=`ls $SAS_ODF/*.SAS`
 echo using $list as odf-file

#--------rgsproc----------------------
echo '  running emproc this will take a while, please be patient...'
  emproc -V 5 >& my_emproc_logfile
  [ $? = 0 ] || die "emproc failed"
echo '  ...done'

echo '  running epproc this will take a while, please be patient...'
  epproc -V 5 >& my_epproc_logfile
  [ $? = 0 ] || die "epproc failed"
echo '  ...done'

#   MOS1/2
efile1=${rev}_${obs}_EMOS1_S001_ImagingEvts.ds
export efile1
efile2=${rev}_${obs}_EMOS2_S002_ImagingEvts.ds
export efile2
efilepn=${rev}_${obs}_EPN_S003_ImagingEvts.ds
export efilepn

# Check for high background (MOS:counts<35 ; PN:counts<100 ??)
evselect table=${efile1} withrateset=true rateset=mos1_he_lc.fits timecolumn=TIME timebinsize=100 maketimecolumn=yes expression="#XMMEA_EM && (PI>10000) && (PATTERN==0)"
evselect table=${efile2} withrateset=true rateset=mos2_he_lc.fits timecolumn=TIME timebinsize=100 maketimecolumn=yes expression="#XMMEA_EM && (PI>10000) && (PATTERN==0)"
evselect table=${efilepn} withrateset=true rateset=pn_he_lc.fits timecolumn=TIME timebinsize=100 maketimecolumn=yes expression="#XMMEA_EP && (PI>10000) && (PATTERN==0)"

# Filter eventfile
tabgtigen table=mos1_he_lc.fits expression="COUNTS<35" gtiset=gti_mos1_he.fits
evselect table=${efile1} withfilteredset=true filteredset=mos1_filt.fits keepfilteroutput=true destruct=yes expression="(#XMMEA_EM && gti(gti_mos1_he.fits,TIME) && (PI in [150:15000]) && (PATTERN<=12))"
tabgtigen table=mos2_he_lc.fits expression="COUNTS<35" gtiset=gti_mos2_he.fits
evselect table=${efile2} withfilteredset=true filteredset=mos2_filt.fits keepfilteroutput=true destruct=yes expression="(#XMMEA_EM && gti(gti_mos2_he.fits,TIME) && (PI in [150:15000]) && (PATTERN<=12))"
tabgtigen table=pn_he_lc.fits expression="COUNTS<100" gtiset=gti_pn_he.fits
evselect table=${efilepn} withfilteredset=true filteredset=pn_filt.fits keepfilteroutput=true destruct=yes expression="(#XMMEA_EP && gti(gti_pn_he.fits,TIME) && (PI in [150:15000]) && (PATTERN<=12))"


# Create skyimage (evtl. ${efile1}!; 1bin 0.05 arcsec for all)
evselect table=mos1_filt.fits withimageset=true imageset=mos1_im.fits xcolumn=X ycolumn=Y imagebinning=binSize ximagebinsize=100 yimagebinsize=100
echo select extraction region with "> ds9 mos1_im.fits &"
evselect table=mos2_filt.fits withimageset=true imageset=mos2_im.fits xcolumn=X ycolumn=Y imagebinning=binSize ximagebinsize=100 yimagebinsize=100
echo select extraction region with "> ds9 mos2_im.fits &"
evselect table=pn_filt.fits withimageset=true imageset=pn_im.fits xcolumn=X ycolumn=Y imagebinning=binSize ximagebinsize=100 yimagebinsize=100
echo select extraction region with "> ds9 pn_im.fits &"
evselect table=${rev}_${obs}_EMOS1_S001_TimingEvts.ds withimageset=true imageset=mos1c_im.fits xcolumn=RAWX ycolumn=RAWY imagebinning=binSize ximagebinsize=100 yimagebinsize=100

#  lightcurves
evselect table=${efile1} withrateset=yes rateset=mos1_lc.fits maketimecolumn=yes timecolumn=TIME timebinsize=10 expression="#XMMEA_EM && (PATTERN<=12) && (PI in [150:15000]) && ((X,Y) IN circle(25875.5,25900.5,2000))"

evselect table=${rev}_${obs}_EMOS1_S001_TimingEvts.ds withrateset=yes rateset=mos1c_lc.fits maketimecolumn=yes timecolumn=TIME timebinsize=10 expression="#XMMEA_EM && (PATTERN<=12) && (PI in [150:15000]) && ((X,Y) IN circle(25925.5,25925.5,2000))"

evselect table=${efile2} withrateset=yes rateset=mos2_lc_36.fits maketimecolumn=yes timecolumn=TIME timebinsize=36 expression="#XMMEA_EM && (PATTERN<=12) && (PI in [150:15000]) && ((X,Y) IN circle(25925.5,25925.5,2000))"

evselect table=${efile2} withrateset=yes rateset=mos2_lc.fits maketimecolumn=yes timecolumn=TIME timebinsize=10 expression="#XMMEA_EM && (PATTERN<=12) && (PI in [150:15000]) && ((X,Y) IN circle(25925.5,25925.5,2000))"

evselect table=${efilepn} withrateset=yes rateset=pn_lc.fits maketimecolumn=yes timecolumn=TIME timebinsize=10 expression="#XMMEA_EP && (PATTERN<=12) && (PI in [150:15000]) && ((X,Y) IN circle(25888,25900.5,2000))"


